@@ -13,15 +13,18 @@ new_project_parser.add_argument('-t', '--template', metavar='PATH', type=str, he
 new_project_parser.add_argument('--remote', metavar='PATH', type=str, help='External template path')
 
 # stack init
-new_project_parser = subparsers.add_parser('init', help='Initalize a new project envirement')
+init_project_parser = subparsers.add_parser('init', help='Initalize a new project envirement')
+init_project_parser.add_argument('--python', metavar='PATH', type=str, help='Version of Python')
+
 
 # stack install
 install_parser = subparsers.add_parser('install', help='Install libs from pypi or git repos')
-install_parser.add_argument('lib', metavar='LIB', type=str, help='Repo path or name of lib')
+install_parser.add_argument('module', metavar='LIB', type=str, help='Repo path or name of lib')
+install_parser.add_argument('--git', metavar='LIB', type=str, help='Declare a git repo')
 
 # stack uninstall
 install_parser = subparsers.add_parser('uninstall', help='Uninstall libs')
-install_parser.add_argument('lib', metavar='LIB', type=str, help='Lib name')
+install_parser.add_argument('module', metavar='LIB', type=str, help='Lib name')
 
 # stack list
 install_parser = subparsers.add_parser('list', help='List installed libs')
